@@ -6,7 +6,7 @@
 pub use crate::context::{Context, ContextFlags};
 pub use crate::device::Device;
 pub use crate::launch;
-pub use crate::memory::{CopyDestination, DBuffer, UnifiedBuffer};
+pub use crate::memory::{CopyDestination, DeviceBuffer, UnifiedBuffer};
 pub use crate::module::Module;
 pub use crate::stream::{Stream, StreamFlags};
 pub use crate::util::*;
